@@ -85,7 +85,7 @@ typedef struct SoundStreamInfoEx_
 	ChannelConfig mChannelConfig;
 } SoundStreamInfoEx;
 
-
+// NOTE: The following enums are part of the ABI! Do not insert new values in the middle - always append them at the end!
 typedef enum EIntConfigKey_
 {
 	zmusic_adl_chips_count,
@@ -151,7 +151,16 @@ typedef enum EIntConfigKey_
 	
 	zmusic_snd_mididevice,
 	zmusic_snd_outputrate,
+	zmusic_mod_preferredplayer,
 
+	// new constants since 1.2.0
+	zmusic_adl_use_genmidi,
+	zmusic_adl_chan_alloc,
+	zmusic_adl_auto_arpeggio,
+	zmusic_opn_volume_model,
+	zmusic_opn_chan_alloc,
+	zmusic_opn_auto_arpeggio,
+	
 	NUM_ZMUSIC_INT_CONFIGS
 } EIntConfigKey;
 
@@ -177,6 +186,11 @@ typedef enum EFloatConfigKey_
 	zmusic_relative_volume,
 	zmusic_snd_mastervolume,
 
+	// new constants since 1.2.0
+	zmusic_opl_gain,
+	zmusic_adl_gain,
+	zmusic_opn_gain,
+	
 	NUM_FLOAT_CONFIGS
 } EFloatConfigKey;
 
